@@ -143,7 +143,7 @@ class Postgres_Handler:
         
         
     #This needs to be looked at, likely there are only certain fields that will be passed and the rest will be created either in lambda or S3/postgresql
-    def insert_row(self, **kwargs):
+    def insert_row(self, kwargs):
         
         #Values dictioniary for sql parameters
         values_dict = {}
